#include <Wire.h>
#include <Adafruit_NFCShield_I2C.h>
#include <LiquidCrystal.h>
// On dit que le LCD est présent en entrée 12 ...
LiquidCrystal lcd(12, 11, 5, 4, 3, 7);
#define IRQ   (2)
#define RESET (3)  // Not connected by default on the NFC Shield

int luminosite = 0;
int ledverte = 13;
int ledrouge = 9;

Adafruit_NFCShield_I2C nfc(IRQ, RESET);


void setup(void) {
  Serial.begin(115200);
  lcd.begin(16, 2);
  Serial.println("Hello!");
  
  nfc.begin();

  uint32_t versiondata = nfc.getFirmwareVersion();
  if (! versiondata) {
    Serial.print("Didn't find PN53x board");
    while (1); // halt
  }
  // Got ok data, print it out!
  Serial.print("Found chip PN5"); Serial.println((versiondata>>24) & 0xFF, HEX); 
  Serial.print("Firmware ver. "); Serial.print((versiondata>>16) & 0xFF, DEC); 
  Serial.print('.'); Serial.println((versiondata>>8) & 0xFF, DEC);
  
  // configure board to read RFID tags
  nfc.SAMConfig();
  
  Serial.println("Waiting for an ISO14443A Card ...");
  pinMode(ledverte,OUTPUT);
  pinMode(ledrouge,OUTPUT);
}


void loop(void) 
{
 //
  lcd.clear();
  lcd.setCursor(0, 0);
  
  uint8_t success;
  uint8_t uid[] = { 0, 0, 0, 0, 0, 0, 0 };  // Buffer to store the returned UID
  uint8_t uidLength;                        // Length of the UID (4 or 7 bytes depending on ISO14443A card type)
    
  // Wait for an ISO14443A type cards (Mifare, etc.).  When one is found
  // 'uid' will be populated with the UID, and uidLength will indicate
  // if the uid is 4 bytes (Mifare Classic) or 7 bytes (Mifare Ultralight)
  success = nfc.readPassiveTargetID(PN532_MIFARE_ISO14443A, uid, &uidLength);
  
  if (success) {
    // Display some basic information about the card
    Serial.println("Found an ISO14443A card");
    Serial.print("  UID Length: ");Serial.print(uidLength, DEC);Serial.println(" bytes");
    Serial.print("  UID Value: ");
    nfc.PrintHex(uid, uidLength);
    Serial.println("");
    
    if (uidLength == 4)
    {
      // We probably have a Mifare Classic card ... 
      Serial.println("Seems to be a Mifare Classic card (4 byte UID)");
    
      // Now we need to try to authenticate it for read/write access
      // Try with the factory default KeyA: 0xFF 0xFF 0xFF 0xFF 0xFF 0xFF
      Serial.println("Trying to authenticate block 4 with default KEYA value");
      uint8_t keya[6] = { 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF };
    
      // Start with block 4 (the first block of sector 1) since sector 0
      // contains the manufacturer data and it's probably better just
      // to leave it alone unless you know what you're doing
      success = nfc.mifareclassic_AuthenticateBlock(uid, uidLength, 4, 0, keya);
    
      if (success)
      {
        Serial.println("Sector 1 (Blocks 4..7) has been authenticated");
        uint8_t data[16];
    
        // If you want to write something to block 4 to test with, uncomment
        // the following line and this text should be read back in a minute
        //memcpy(data, (const uint8_t[]){ 'a', 'd', 'a', 'f', 'r', 'u', 'i', 't', '.', 'c', 'o', 'm', 0, 0, 0, 0 }, sizeof data);
        //success = nfc.mifareclassic_WriteDataBlock (4, data);

        // Try to read the contents of block 4
        success = nfc.mifareclassic_ReadDataBlock(4, data);
    
        if (success)
        {
          // Data seems to have been read ... spit it out
          Serial.println("Reading Block 4:");
          nfc.PrintHexChar(data, 16);
          Serial.println("");
      
      // C'est ici que l'on met les identifiants des cartes !
      
          if (uid[0] == 0x03 && uid[1] == 0x18)
          {
            Serial.println("Jean-Jacques");
            lcd.setCursor(0, 0);
            lcd.print("Bienvenue");
            lcd.setCursor(0, 1);
            lcd.print("Jean-Jacques");
            digitalWrite(ledverte,HIGH);
            delay(1000);
            digitalWrite(ledverte,LOW);
            delay(500);
            
          }
         
          if (uid[0] == 0x53 && uid[1] == 0x16 && uid[2] == 0x19 && uid[3] == 0x99)
          {
            Serial.println("Micheline");
            lcd.setCursor(0, 0);
            lcd.print("Bienvenue");
            lcd.setCursor(0, 1);
            lcd.print("Micheline");
            digitalWrite(ledverte,HIGH);
            delay(1000);
            digitalWrite(ledverte,LOW);
            delay(500);
           
          }
          
          if (uid[0] == 0xD3 && uid[1] == 0x51)
          {
            Serial.println("Visiteur");
            lcd.setCursor(0, 0);
            lcd.print("Visiteur");
            lcd.setCursor(0, 1);
            lcd.print("Voir accueil");
            digitalWrite(ledverte,HIGH);
            delay(1000);
            digitalWrite(ledverte,LOW);
            delay(500);
            
          }
          
          if (uid[0] == 0xD3 && uid[1] == 0x7E  && uid[2] == 0x28  && uid[3] == 0xD4)
          {
            Serial.println("ERREUR");
            lcd.setCursor(0, 0);
            lcd.print("Vous ne pouvez");
            lcd.setCursor(0, 1);
            lcd.print("Pas entrer");
            digitalWrite(ledrouge,HIGH);
            delay(1000);
            digitalWrite(ledrouge,LOW);
            delay(500);
          }
          
         
      
          // Wait a bit before reading the card again
          delay(1000);
        }
        else
        {
          Serial.println("Entrée non autorisée");
          lcd.setCursor(0, 0);
            lcd.print("Votre carte");
            lcd.setCursor(0, 1);
            lcd.print("n'est pas valide");
            digitalWrite(ledrouge,HIGH);
            delay(1000);
            digitalWrite(ledrouge,LOW);
            delay(500);
        }
      }
      else
      {
        Serial.println("Entrée non autorisée");
        lcd.setCursor(0, 0);
            lcd.print("Votre carte");
            lcd.setCursor(0, 1);
            lcd.print("n'est pas valide");
            digitalWrite(ledrouge,HIGH);
            delay(1000);
            digitalWrite(ledrouge,LOW);
            delay(500);
            
      }
    }
    
    if (uidLength == 7)
    {
      // We probably have a Mifare Ultralight card ...
      Serial.println("Seems to be a Mifare Ultralight tag (7 byte UID)");
    
      // Try to read the first general-purpose user page (#4)
      Serial.println("Reading page 4");
      uint8_t data[32];
      success = nfc.mifareultralight_ReadPage (4, data);
      if (success)
      {
        // Data seems to have been read ... spit it out
        nfc.PrintHexChar(data, 4);
        Serial.println("");
    
        // Wait a bit before reading the card again
        delay(1000);
      }
      else
      {
        Serial.println("Ooops ... unable to read the requested page!?");
      }
    }
  }
}

